searchData={"items":[{"type":"module","title":"Ueberauth.Strategy.Oidcc","doc":"OIDC Strategy for Ueberauth.","ref":"Ueberauth.Strategy.Oidcc.html"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.credentials/1","doc":"Returns the credentials from the oidc response.\n\n`other` includes `id_token`","ref":"Ueberauth.Strategy.Oidcc.html#credentials/1"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.default_options/0","doc":"","ref":"Ueberauth.Strategy.Oidcc.html#default_options/0"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.extra/1","doc":"Returns an `Ueberauth.Auth.Extra` struct containing the claims and userinfo response.","ref":"Ueberauth.Strategy.Oidcc.html#extra/1"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.handle_callback!/1","doc":"Handles the callback from the oidc provider.","ref":"Ueberauth.Strategy.Oidcc.html#handle_callback!/1"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.handle_request!/1","doc":"Handles the initial authentication request.","ref":"Ueberauth.Strategy.Oidcc.html#handle_request!/1"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.info/1","doc":"Returns a `Ueberauth.Auth.Info` struct populated with the data returned from\nthe userinfo endpoint.\n\nThis information is also included in the `Ueberauth.Auth.Credentials` struct.","ref":"Ueberauth.Strategy.Oidcc.html#info/1"},{"type":"function","title":"Ueberauth.Strategy.Oidcc.uid/1","doc":"Returns the configured uid field from the claims.","ref":"Ueberauth.Strategy.Oidcc.html#uid/1"},{"type":"module","title":"UeberauthOidcc","doc":"Documentation for `UeberauthOidcc`.","ref":"UeberauthOidcc.html"},{"type":"function","title":"UeberauthOidcc.initiate_logout_url/2","doc":"Create a logout URL for a given `t:Ueberauth.Auth.t/0` struct.\n\nAlso takes a an map of query parameters to append to the URL.","ref":"UeberauthOidcc.html#initiate_logout_url/2"},{"type":"module","title":"UeberauthOidcc.RawInfo","doc":"Struct for the data passed to the callback as `s:Ueberauth.Auth.Extra` `raw_info`.","ref":"UeberauthOidcc.RawInfo.html"},{"type":"type","title":"UeberauthOidcc.RawInfo.string_map/0","doc":"","ref":"UeberauthOidcc.RawInfo.html#t:string_map/0"},{"type":"type","title":"UeberauthOidcc.RawInfo.t/0","doc":"","ref":"UeberauthOidcc.RawInfo.html#t:t/0"},{"type":"extras","title":"UeberauthOidcc","doc":"# UeberauthOidcc\n\nImplementation of [Ueberauth.Strategy](https://hexdocs.pm/ueberauth/Ueberauth.Strategy.html) based on the [Oidcc](https://hexdocs.pm/oidcc/readme.html) library.","ref":"readme.html"},{"type":"extras","title":"Installation - UeberauthOidcc","doc":"The package can be installed by adding `ueberauth_oidcc` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ueberauth_oidcc, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - UeberauthOidcc","doc":"1. Add an OIDC Issuer to your Ueberauth configuration.\n\nAn issuer is a single OIDC endpoint, but it can be shared by multiple\nstrategies.\n\n``` elixir\nconfig :ueberauth_oidcc, :issuers, [\n  %{name: :oidcc_issuer, issuer: \" \"}\n]\n```\n\nThe issuer must provide OIDC configuration at ` /.well-known/openid-configuration`.\n\nSee\n[oidcc_provider_configuration:opts/0](https://hexdocs.pm/oidcc/oidcc_provider_configuration.html#t:opts/0) for issuer parameters.\n\n2. Add the Ueberauth strategy to your configuration.\n\nSee [Ueberauth](https://hexdocs.pm/ueberauth/readme.html#configuring-providers) and [Oidcc](https://hexdocs.pm/oidcc/Oidcc.html#create_redirect_url/4) for a list of supported options.\n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        oidc: { Ueberauth.Strategy.Oidcc,\n          issuer: :oidcc_issuer, # matches the name above\n          client_id: \"client_id\",\n          client_secret: \"123456789\",\n          scopes: [\"openid\", \"profile\", \"email\"],\n          # optional\n          callback_path: \"/auth/oidc/callback\",\n          userinfo: true, # whether to pull info from the Userinfo endpoint, default: false\n          uid_field: \"email\", # pulled from the merge of the claims and userinfo (if fetched), default: sub\n          authorization_params: %{}, # additional parameters for the authorization request\n          authorization_endpoint: \"https://oidc-override/request\" # override the initial request URI\n        }\n      ]\n    ```\nThe core Ueberauth configuration is only read at compile time, so if you have runtime configuration you'll need to put it under the `:ueberauth_oidcc` `:strategies` config. \n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        oidc: { Ueberauth.Strategy.Oidcc,\n          issuer: :oidcc_issuer,\n          client_id: \"client_id\"\n        }\n      ]\n\n    config :ueberauth_oidcc, :strategies,\n      oidc: [\n        client_secret: System.fetch_env!(\"OIDC_CLIENT_SECRET\")\n      ]\n    ```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - UeberauthOidcc","doc":"1. Include the Ueberauth plug in your controller:\n\n    ```elixir\n    defmodule MyApp.AuthController do\n      use MyApp.Web, :controller\n      plug Ueberauth\n      ...\n    end\n    ```\n\n1. Create the request and callback routes if you haven't already:\n\n    ```elixir\n    scope \"/auth\", MyApp do\n      pipe_through :browser\n\n      get \"/:unused\", AuthController, :request\n      get \"/:unused/callback\", AuthController, :callback\n    end\n    ```\n\n1. Your controller needs to implement callbacks to deal with `Ueberauth.Auth`\nand `Ueberauth.Failure` responses. For an example implementation see the\n[Ueberauth Example](https://github.com/ueberauth/ueberauth_example) application.\n\n   - `Ueberauth.Auth.Credentials` contains the `access_token` and related fields\n     - The `other` map in `Ueberauth.Auth.Credentials` contains `id_token`\n   - `Ueberauth.Auth.Extra` contains the raw claims, userinfo, and options","ref":"readme.html#usage"},{"type":"extras","title":"Calling - UeberauthOidcc","doc":"Depending on the configured url, you can initialize the request through:\n\n    /auth/oidc","ref":"readme.html#calling"},{"type":"extras","title":"Documentation - UeberauthOidcc","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand or found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"License - UeberauthOidcc","doc":"Released under the MIT License. Please see [LICENSE](./LICENSE) for details.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2023 Paul Swartz\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}